@@ -2516,6 +2516,8 @@ gi_marshalling_tests_flags_get_type (void)
             { GI_MARSHALLING_TESTS_FLAGS_VALUE1, "GI_MARSHALLING_TESTS_FLAGS_VALUE1", "value1" },
             { GI_MARSHALLING_TESTS_FLAGS_VALUE2, "GI_MARSHALLING_TESTS_FLAGS_VALUE2", "value2" },
             { GI_MARSHALLING_TESTS_FLAGS_VALUE3, "GI_MARSHALLING_TESTS_FLAGS_VALUE3", "value3" },
+            { GI_MARSHALLING_TESTS_FLAGS_MASK,   "GI_MARSHALLING_TESTS_FLAGS_MASK",   "mask"   },
+            { GI_MARSHALLING_TESTS_FLAGS_MASK2,  "GI_MARSHALLING_TESTS_FLAGS_MASK2",  "mask2"  },
             { 0, NULL, NULL }
         };
         type = g_flags_register_static (g_intern_static_string ("GIMarshallingTestsFlags"), values);
@@ -2564,6 +2566,46 @@ gi_marshalling_tests_flags_inout (GIMarshallingTestsFlags *flags_)
 }
 
 
+GIMarshallingTestsNoTypeFlags
+gi_marshalling_tests_no_type_flags_returnv (void)
+{
+    return GI_MARSHALLING_TESTS_NO_TYPE_FLAGS_VALUE2;
+}
+
+void
+gi_marshalling_tests_no_type_flags_in (GIMarshallingTestsNoTypeFlags flags_)
+{
+    g_assert(flags_ == GI_MARSHALLING_TESTS_NO_TYPE_FLAGS_VALUE2);
+}
+
+void
+gi_marshalling_tests_no_type_flags_in_zero (GIMarshallingTestsNoTypeFlags flags)
+{
+    g_assert(flags == 0);
+}
+
+/**
+ * gi_marshalling_tests_no_type_flags_out:
+ * @flags_: (out):
+ */
+void
+gi_marshalling_tests_no_type_flags_out (GIMarshallingTestsNoTypeFlags *flags_)
+{
+    *flags_ = GI_MARSHALLING_TESTS_NO_TYPE_FLAGS_VALUE2;
+}
+
+/**
+ * gi_marshalling_tests_no_type_flags_inout:
+ * @flags_: (inout):
+ */
+void
+gi_marshalling_tests_no_type_flags_inout (GIMarshallingTestsNoTypeFlags *flags_)
+{
+    g_assert(*flags_ == GI_MARSHALLING_TESTS_NO_TYPE_FLAGS_VALUE2);
+    *flags_ = GI_MARSHALLING_TESTS_NO_TYPE_FLAGS_VALUE1;
+}
+
+
 /**
  * gi_marshalling_tests_simple_struct_returnv:
  * Returns: (transfer none):
@@ -3230,6 +3272,24 @@ gi_marshalling_tests_int_out_out (gint *int0, gint *int1)
     *int1 = 7;
 }
 
+/**
+ * gi_marshalling_tests_int_three_in_three_out:
+ * @a: (in):
+ * @b: (in):
+ * @c: (in):
+ * @out0: (out):
+ * @out1: (out):
+ * @out2: (out):
+ */
+void
+gi_marshalling_tests_int_three_in_three_out(gint a, gint b, gint c,
+                                            gint *out0, gint *out1, gint *out2)
+{
+    *out0 = a;
+    *out1 = b;
+    *out2 = c;
+}
+
 /**
  * gi_marshalling_tests_int_return_out:
  * @int_: (out):
@@ -3253,6 +3313,20 @@ gi_marshalling_tests_gerror(GError **error)
                         GI_MARSHALLING_TESTS_CONSTANT_GERROR_MESSAGE);
 }
 
+/**
+ * gi_marshalling_tests_gerror_array_in:
+ * @in_ints: (array zero-terminated=1):
+ */
+void
+gi_marshalling_tests_gerror_array_in(gint *in_ints, GError **error)
+{
+    GQuark quark = g_quark_from_static_string(GI_MARSHALLING_TESTS_CONSTANT_GERROR_DOMAIN);
+    g_set_error_literal(error,
+                        quark,
+                        GI_MARSHALLING_TESTS_CONSTANT_GERROR_CODE,
+                        GI_MARSHALLING_TESTS_CONSTANT_GERROR_MESSAGE);
+}
+
 static GIMarshallingTestsOverridesStruct *
 gi_marshalling_tests_overrides_struct_copy (GIMarshallingTestsOverridesStruct *struct_)
 {
